From: Davide Libenzi Date: Mon, 16 Oct 2006 18:30:59 GMT Subject: Re: git-diff-tree inordinately (O(M*N)) slow on files with many changes Message-ID: In-Reply-To: <873b9op19n.fsf@rho.meyering.net> On Mon, 16 Oct 2006, Jim Meyering wrote: > IMHO, my "&& vs. ||" patch is still worth applying. > If not, then the existing code doesn't make sense, and > there can be significant simplification in the affected loops. > With my patch, I get an additional 3x speed-up: diff-tree takes 0.7s No, the patch is broken. It will discard *any* line seen at least two times, that is an extremely low threashold. - Davide